@@ -69,24 +69,24 @@ class RedisStorage(AbstractStorage):
         if cookie is None:
             return Session(None, data=None, new=True, max_age=self.max_age)
         else:
-            with await self._redis as conn:
-                key = str(cookie)
-                # update 2018.9.28 for cxh
-                data = await conn.get('session:' + key)
-                if data is None:
-                    return Session(None, data=None,
-                                   new=True, max_age=self.max_age)
-                data = data.decode('utf-8')
-                try:
-                    session_data = self._decoder(data)
-                    # 确保框架能识别,sessionz的有效，由redis key的exp时间保证，可以忽略created，值取now，是为了框架的age能有效
-                    data = {
-                         'created':session_data.get('created',int(time.time())),
-                         'session': session_data
-                    }
-                except ValueError:
-                    data = None
-                return Session(key, data=data, new=False, max_age=self.max_age)
+            # with await self._redis as conn:
+            key = str(cookie)
+            # update 2018.9.28 for cxh
+            data = await self._redis.get('session:' + key)
+            if data is None:
+                return Session(None, data=None,
+                               new=True, max_age=self.max_age)
+            data = data.decode('utf-8')
+            try:
+                session_data = self._decoder(data)
+                # 确保框架能识别,sessionz的有效，由redis key的exp时间保证，可以忽略created，值取now，是为了框架的age能有效
+                data = {
+                     'created':session_data.get('created',int(time.time())),
+                     'session': session_data
+                }
+            except ValueError:
+                data = None
+            return Session(key, data=data, new=False, max_age=self.max_age)
 
     def _get_session_data(self, session):
         if not session.empty:
